@@ -16,7 +16,7 @@ log.addFilter(utils.warning_filter)
 
 
 def write_html(site_dir, old_path, new_path):
-    """ Write an HTML file in the site_dir with a meta redirect to the new page """
+    """Write an HTML file in the site_dir with a meta redirect to the new page"""
     # Determine all relevant paths
     old_path_abs = os.path.join(site_dir, old_path)
     old_dir = os.path.dirname(old_path)
@@ -29,9 +29,8 @@ def write_html(site_dir, old_path, new_path):
 
     # Write the HTML redirect file in place of the old file
     with open(old_path_abs, 'w', encoding='utf-8') as f:
-        log.debug("Creating redirect: '%s' -> '%s'",
-                  old_path, new_path)
-        f.write(textwrap.dedent(
+        log.debug("Creating redirect: '%s' -> '%s'", old_path, new_path)
+        content = textwrap.dedent(
             """
             <!doctype html>
             <html lang="en">
@@ -48,13 +47,15 @@ def write_html(site_dir, old_path, new_path):
             </body>
             </html>
             """
-        ).format(url=new_path))
+        ).format(url=new_path)
+        f.write(content)
 
 
 def get_relative_html_path(old_page, new_page, use_directory_urls):
-    """ Return the relative path from the old html path to the new html path"""
+    """Return the relative path from the old html path to the new html path"""
     old_path = get_html_path(old_page, use_directory_urls)
-    new_path = get_html_path(new_page, use_directory_urls)
+    new_path, new_hash_fragment = _split_hash_fragment(new_page)
+    new_path = get_html_path(new_path, use_directory_urls)
 
     if use_directory_urls:
         # remove /index.html from end of path
@@ -65,11 +66,11 @@ def get_relative_html_path(old_page, new_page, use_directory_urls):
     if use_directory_urls:
         relative_path = relative_path + '/'
 
-    return relative_path
+    return relative_path + new_hash_fragment
 
 
 def get_html_path(path, use_directory_urls):
-    """ Return the HTML file path for a given markdown file """
+    """Return the HTML file path for a given markdown file"""
     parent, filename = posixpath.split(path)
     name_orig = posixpath.splitext(filename)[0]
 
@@ -104,18 +105,20 @@ class RedirectPlugin(BasePlugin):
 
         # SHIM! Produce a warning if the old root-level 'redirects' config is present
         if config.get('redirects'):
-            log.warn("The root-level 'redirects:' setting is not valid and has been changed in version 1.0! "
-                     "The plugin-level 'redirect-map' must be used instead. See https://git.io/fjdBN")
+            log.warning(
+                "The root-level 'redirects:' setting is not valid and has been changed in version 1.0! "
+                "The plugin-level 'redirect-map' must be used instead. See https://git.io/fjdBN"
+            )
 
         # Validate user-provided redirect "old files"
         for page_old in self.redirects.keys():
             if not utils.is_markdown_file(page_old):
-                log.warn("redirects plugin: '%s' is not a valid markdown file!", page_old)
+                log.warning("redirects plugin: '%s' is not a valid markdown file!", page_old)
 
         # Build a dict of known document pages to validate against later
         self.doc_pages = {}
         for page in files.documentation_pages():  # object type: mkdocs.structure.files.File
-            self.doc_pages[page.src_path.replace('\\', '/')] = page
+            self.doc_pages[page.src_path.replace(os.sep, '/')] = page
 
     # Create HTML files for redirects after site dir has been built
     def on_post_build(self, config, **kwargs):
@@ -125,21 +128,36 @@ class RedirectPlugin(BasePlugin):
 
         # Walk through the redirect map and write their HTML files
         for page_old, page_new in self.redirects.items():
+            # Need to remove hash fragment from new page to verify existence
+            page_new_without_hash, _ = _split_hash_fragment(str(page_new))
 
             # External redirect targets are easy, just use it as the target path
             if page_new.lower().startswith(('http://', 'https://')):
                 dest_path = page_new
 
-            elif page_new in self.doc_pages:
+            elif page_new_without_hash in self.doc_pages:
                 dest_path = get_relative_html_path(page_old, page_new, use_directory_urls)
 
             # If the redirect target isn't external or a valid internal page, throw an error
             # Note: we use 'warn' here specifically; mkdocs treats warnings specially when in strict mode
             else:
-                log.warn("Redirect target '%s' does not exist!", page_new)
+                log.warning("Redirect target '%s' does not exist!", page_new)
                 continue
 
             # DO IT!
-            write_html(config['site_dir'],
-                       get_html_path(page_old, use_directory_urls),
-                       dest_path)
+            write_html(
+                config['site_dir'],
+                get_html_path(page_old, use_directory_urls),
+                dest_path,
+            )
+
+
+def _split_hash_fragment(path):
+    """
+    Returns (path, hash-fragment)
+
+    "path/to/file#hash" => ("/path/to/file", "#hash")
+    "path/to/file"      => ("/path/to/file", "")
+    """
+    path, hash, after = path.partition('#')
+    return path, hash + after
